/* mp3topttag.cc - mp3t option parsing

   This file is part of MP3T - The MP3 tag command line editor

   (c) 2000 by Martin Pitt (Piware; www.piware.de)

   This file is distributed under the terms and conditions of the "GNU
   General Public License" (see file COPYING). 

   Please send bug reports, questions and suggestions to:
   piware@piware.de
*/

#include "mp3topts.h"
#include "mp3ttools.h" // getGenre()
#include <getopt.h>
#include <string.h> // strcpy()

bool optt = false, opta = false, optn = false, opty = false, 
    optc = false, optg = false;
Tag opttag;
char mode = 'r';
char* format;

bool
processOptions( int argc, char** argv )
{
    static const char stdformat[] = "File   : %FILE\nTitle  : %TITLE\nAlbum  :"
	" %ALBUM\nArtist : %ARTIST\nComment: %COMMENT\nYear   :"
	" %YEAR\nGenre  : %GENRE\n\n";

    static struct option longOptions[] = {
	{"read", 2, 0, 'r'},
	{"write", 0, 0, 'w'},
	{"input", 0, 0, 'i'},
	{"delete", 0, 0, 'd'},
	{"title", 1, 0, 't'},
	{"album", 1, 0, 'a'},
	{"artist", 1, 0, 'n'},
	{"year", 1, 0, 'y'},
	{"comment", 1, 0, 'c'},
	{"genre", 1, 0, 'g'},
	{"genres", 0, 0, 'x'},
	{"help", 0, 0, 'h'},
	{"version", 0, 0, 'v'}
    };

    int longIndex, o, genre;

    format = new char[sizeof( stdformat )];
    strcpy( format, stdformat );

    while ((o = getopt_long( argc, argv, "r::widt:a:n:y:c:g:hv", longOptions, &longIndex)) != EOF )
	switch (o)
	 {
	     case 't' : opttag.setTitle( optarg ); optt = true; break;
	     case 'a' : opttag.setAlbum( optarg ); opta = true; break;
	     case 'n' : opttag.setArtist( optarg ); optn = true; break;
	     case 'y' : opttag.setYear( optarg ); opty = true; break;
	     case 'c' : opttag.setComment( optarg ); optc = true; break;
	     case 'g' : if( ( genre = getGenre( optarg ) ) == -1 ) {
			    genre = Tag::genre_largest;
			    fprintf( stderr, "error: unknown genre. Using 'Unknown'\n" );
			}
		        opttag.setGenre( genre );
			optg = true;
	     		break;
		 
	     case '?':
	     case ':': return false;

	     case 'r': if( optarg ) {
		 	 delete format;
			 strcpy( format= new char[strlen( optarg )], optarg );
	               }
	     
	     default : mode = o; // h x v r i w d
	 }

    return true;
}
